@@ -253,12 +253,13 @@ class MCP23017(MCP230XX):
         Bit 4 is whether SDA slew rate is enabled (1 = yes). Bit 5 is if I2C
         address pointer auto-increments (1 = no). Bit 6 is whether interrupt
         pins are internally connected (1 = yes). Bit 7 is whether registers
-        are all in one bank (1 = no).
+        are all in one bank (1 = no), this is silently ignored if set to ``1``.
         """
         return self._read_u8(_MCP23017_IOCON)
 
     @io_control.setter
     def io_control(self, val):
+        val &= ~0x80
         self._write_u8(_MCP23017_IOCON, val)
 
     @property
@@ -289,6 +290,31 @@ class MCP23017(MCP230XX):
         flags = [pin + 8 for pin in range(8) if intfb & (1 << pin)]
         return flags
 
+    @property
+    def int_cap(self):
+        """Returns a list with the pin values at time of interrupt
+        port A ----> pins 0-7
+        port B ----> pins 8-15
+        """
+        intcap = self._read_u16le(_MCP23017_INTCAPA)
+        return [(intcap >> pin) & 1 for pin in range(16)]
+
+    @property
+    def int_capa(self):
+        """Returns a list of pin values at time of interrupt
+        pins: 0-7
+        """
+        intcapa = self._read_u8(_MCP23017_INTCAPA)
+        return [(intcapa >> pin) & 1 for pin in range(8)]
+
+    @property
+    def int_capb(self):
+        """Returns a list of pin values at time of interrupt
+        pins: 8-15
+        """
+        intcapb = self._read_u8(_MCP23017_INTCAPB)
+        return [(intcapb >> pin) & 1 for pin in range(8)]
+
     def clear_ints(self):
         """Clears interrupts by reading INTCAP."""
         self._read_u16le(_MCP23017_INTCAPA)
